summaryrefslogtreecommitdiffstats
path: root/Bugzilla/Search.pm
diff options
context:
space:
mode:
Diffstat (limited to 'Bugzilla/Search.pm')
-rw-r--r--Bugzilla/Search.pm4
1 files changed, 2 insertions, 2 deletions
diff --git a/Bugzilla/Search.pm b/Bugzilla/Search.pm
index 0c9f84689..0c5b65acf 100644
--- a/Bugzilla/Search.pm
+++ b/Bugzilla/Search.pm
@@ -2797,8 +2797,8 @@ sub _changedby {
sub IsValidQueryType
{
my ($queryType) = @_;
- # BMO: Added google query type
- if (grep { $_ eq $queryType } qw(specific advanced google)) {
+ # BMO: Added google and instant
+ if (grep { $_ eq $queryType } qw(specific advanced google instant)) {
return 1;
}
return 0;